@@ -4,7 +4,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use Text::Template::Simple::Constants qw( :info DIGEST_MODS );
 use Carp qw( croak );
 
-$VERSION = '0.54_14';
+$VERSION = '0.60';
 
 BEGIN {
    if ( IS_WINDOWS ) {
@@ -54,6 +54,10 @@ my %ERROR = (
               ."Please upgrade this module!",
    PFORMAT  => "Parameters must be in 'param => value' format",
    INCACHE  => "I need an 'id' or a 'data' parameter for cache check!",
+   DSLEN    => "Start delimiter is smaller than 2 characters",
+   DELEN    => "End delimiter is smaller than 2 characters",
+   DSWS     => "Start delimiter contains whitespace",
+   DEWS     => "End delimiter contains whitespace",
 );
 
 my $DEBUG = 0;  # Disabled by default
